@@ -13,7 +13,7 @@ np.seterr(divide='ignore', invalid='ignore')
 
 ' a function for calculating the neural pattern similarity for EEG-like data '
 
-def nps(data, time_win=5, sub_opt=0):
+def nps(data, time_win=5, time_step=5, sub_opt=0):
 
     """
     Calculate the Neural Representational Similarity (NPS) for EEG-like data
@@ -28,7 +28,8 @@ def nps(data, time_win=5, sub_opt=0):
     time_win : int. Default is 5.
         Set a time-window for calculating the NPS for different time-points.
         If time_win=5, that means each calculation process based on 5 time-points.
-        This is also a processing of downsampling.
+    time_step : int. Default is 5.
+        The time step size for each time of calculating.
     sub_opt : int 0 or 1. Default is 0.
         Calculate the NPS for each subject or not.
         If sub_opt=0, calculate the NPS based on all data.
@@ -38,8 +39,8 @@ def nps(data, time_win=5, sub_opt=0):
     -------
     NPS : array
         The EEG-like NPS.
-        If sub_opt=0, the shape of NPS is [n_chls, int(n_ts/time_win), 2].
-        If sub_opt=1, the shape of NPS is [n_subs, n_chls, int(n_ts/time_win), 2].
+        If sub_opt=0, the shape of NPS is [n_chls, int((n_ts-time_win)/time_step)+1, 2].
+        If sub_opt=1, the shape of NPS is [n_subs, n_chls, int((n_ts-time_win)/time_step)+1, 2].
         2 representation a r-value and a p-value.
     """
 
@@ -50,7 +51,7 @@ def nps(data, time_win=5, sub_opt=0):
     avgdata = np.average(data, axis=2)
 
     # the time-points for calculating NPS
-    ts = int(nts/time_win)
+    ts = int((nts-time_win)/time_step)+1
 
     # sub_opt=1
     if sub_opt == 1:
@@ -103,7 +104,7 @@ def nps_fmri(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1]):
 
     Parameters
     ----------
-    fmri_data : array [nx, ny, nz].
+    fmri_data : array [nx, ny, nz]
         The fmri data.
         The shape of fmri_data must be [n_cons, n_chls, nx, ny, nz].
         n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
@@ -187,7 +188,7 @@ def nps_fmri_roi(fmri_data, mask_data):
 
     Parameters
     ----------
-    fmri_data : array [nx, ny, nz].
+    fmri_data : array [nx, ny, nz]
         The fmri data.
         The shape of fmri_data must be [n_cons, n_chls, nx, ny, nz].
         n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
